enprot-ffi 0.5.11

C FFI for enprot — shared library (libenprot) for Python, Node.js, Go, Ruby bindings
docs.rs failed to build enprot-ffi-0.5.11
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.